@@ -1,4 +1,5 @@
 # Copyright (c) 2003-2009 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2009 Arista Networks, Inc.
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -28,7 +29,7 @@ from pylint.checkers import BaseChecker
 
 import re
 
-# regex for class/function/variable/constant nane
+# regex for class/function/variable/constant name
 CLASS_NAME_RGX = re.compile('[A-Z_][a-zA-Z0-9]+$')
 MOD_NAME_RGX = re.compile('(([a-z_][a-z0-9_]*)|([A-Z][a-zA-Z0-9]+))$')
 CONST_NAME_RGX = re.compile('(([A-Z_][A-Z0-9_]*)|(__.*__))$')
@@ -118,7 +119,9 @@ MSGS = {
               'Used when a "return" statement with an argument is found '
               'outside in a generator function or method (e.g. with some '
               '"yield" statements).'),
-
+    'E0107': ("Use of the non-existent %s operator",
+              "Used when you attempt to use the C-style pre-increment or"
+              "pre-decrement operator -- and ++, which doesn't exist in Python."),
     'W0101': ('Unreachable code',
               'Used when there is some code behind a "return" or "raise" \
               statement, which will never be accessed.'),
@@ -141,7 +144,9 @@ MSGS = {
               on the same argument list as the lambda itself; such lambda \
               expressions are in all but a few cases replaceable with the \
               function being called in the body of the lambda.'),
-
+    'W0109': ("Duplicate key %r in dictionary",
+              "Used when a dictionary expression binds the same key multiple \
+              times."),
     'W0122': ('Use of the exec statement',
               'Used when you use the "exec" statement, to discourage its \
               usage. That doesn\'t mean you can not use it !'),
@@ -180,7 +185,7 @@ class BasicChecker(BaseChecker):
     """checks for :
     * doc strings
     * modules / classes / functions / methods / arguments / variables name
-    * number of arguments, local variables, branchs, returns and statements in
+    * number of arguments, local variables, branches, returns and statements in
 functions, methods
     * required module attributes
     * dangerous default values as arguments
@@ -505,7 +510,7 @@ functions, methods
         self._check_unreachable(node)
 
     def visit_exec(self, node):
-        """just pring a warning on exec statements"""
+        """just print a warning on exec statements"""
         self.add_message('W0122', node=node)
 
     def visit_callfunc(self, node):
@@ -514,7 +519,7 @@ functions, methods
         """
         if isinstance(node.func, astng.Name):
             name = node.func.name
-            # ignore the name if it's not a builtin (ie not defined in the
+            # ignore the name if it's not a builtin (i.e. not defined in the
             # locals nor globals scope)
             if not (node.frame().has_key(name) or
                     node.root().has_key(name)):
@@ -533,6 +538,23 @@ functions, methods
                         return # W0142 can be skipped
             self.add_message('W0142', node=node.func)
 
+    def visit_unaryop(self, node):
+        """check use of the non-existent ++ adn -- operator operator"""
+        if ((node.op in '+-') and
+            isinstance(node.operand, astng.UnaryOp) and
+            (node.operand.op == node.op)):
+            self.add_message('E0107', node=node, args=node.op*2)
+
+    def visit_dict(self, node):
+        """check duplicate key in dictionary"""
+        keys = set()
+        for k, v in node.items:
+            if isinstance(k, astng.Const):
+                key = k.value
+                if key in keys:
+                    self.add_message('W0109', node=node, args=key)
+                keys.add(key)
+
 
     def _check_unreachable(self, node):
         """check unreachable code"""
