@@ -14,7 +14,7 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-"""a similarties / code duplication command line tool and pylint checker
+"""a similarities / code duplication command line tool and pylint checker
 """
 from __future__ import generators
 
