@@ -35,7 +35,8 @@ import os
 import re
 import tokenize
 
-from logilab.common.configuration import UnsupportedAction, OptionsManagerMixIn, check_csv
+from logilab.common.configuration import UnsupportedAction, OptionsManagerMixIn
+from logilab.common.optik_ext import check_csv
 from logilab.common.modutils import load_module_from_name
 from logilab.common.interface import implements
 from logilab.common.textutils import splitstrip
@@ -70,18 +71,18 @@ REPORTER_OPT_MAP = {'text': TextReporter,
 
 MSGS = {
     'F0001': ('%s',
-              'Used when an error occured preventing the analysis of a \
+              'Used when an error occurred preventing the analysis of a \
               module (unable to find it for instance).'),
     'F0002': ('%s: %s',
-              'Used when an unexpected error occured while building the ASTNG \
+              'Used when an unexpected error occurred while building the ASTNG \
               representation. This is usually accompanied by a traceback. \
               Please report such errors !'),
     'F0003': ('ignored builtin module %s',
               'Used to indicate that the user asked to analyze a builtin module\
               which has been skipped.'),
-    'F0004': ('unexpected infered value %s',
+    'F0004': ('unexpected inferred value %s',
               'Used to indicate that some value of an unexpected type has been \
-              infered.'),
+              inferred.'),
 
     'I0001': ('Unable to run raw checkers on built-in module %s',
               'Used to inform that a built-in module has not been checked \
@@ -185,7 +186,7 @@ Reports (if any) will be written in a file name "pylint_global.[txt|html]".'}),
                 {'default': 1, 'type' : 'yn', 'metavar' : '<y_or_n>',
                  'short': 'r',
                  'group': 'Reports',
-                 'help' : 'Tells wether to display a full report or only the\
+                 'help' : 'Tells whether to display a full report or only the\
  messages'}),
 
                ('evaluation',
@@ -195,7 +196,7 @@ Reports (if any) will be written in a file name "pylint_global.[txt|html]".'}),
 convention) / statement) * 10)',
                  'help' : 'Python expression which should return a note less \
 than 10 (10 is the highest note). You have access to the variables errors \
-warning, statement which respectivly contain the number of errors / warnings\
+warning, statement which respectively contain the number of errors / warnings\
  messages and the total number of statements analyzed. This is used by the \
  global evaluation report (R0004).'}),
 
@@ -430,7 +431,7 @@ This is used by the global evaluation report (R0004).'}),
             self.collect_block_lines(child, msg_state)
         first = node.fromlineno
         last = node.tolineno
-        # first child line number used to distinguate between disable-msg
+        # first child line number used to distinguish between disable-msg
         # which are the first child of scoped node with those defined later.
         # For instance in the code below:
         #
@@ -635,7 +636,7 @@ This is used by the global evaluation report (R0004).'}),
         try:
             note = eval(evaluation, {}, self.stats)
         except Exception, ex:
-            msg = 'An exception occured while rating: %s' % ex
+            msg = 'An exception occurred while rating: %s' % ex
         else:
             stats['global_note'] = note
             msg = 'Your code has been rated at %.2f/10' % note
@@ -665,7 +666,7 @@ def report_messages_stats(sect, stats, _):
                 if not msg_id.startswith('I')]
     in_order.sort()
     in_order.reverse()
-    lines = ('message id', 'occurences')
+    lines = ('message id', 'occurrences')
     for value, msg_id in in_order:
         lines += (msg_id, str(value))
     sect.append(Table(children=lines, cols=2, rheaders=1))
@@ -786,6 +787,12 @@ exit. The value may be a comma separated list of message ids.'''}),
              {'action' : 'callback', 'metavar': '<msg-id>',
               'callback' : self.cb_list_messages,
               'group': 'Commands',
+              'help' : "Generate pylint's messages."}),
+
+            ('full-documentation',
+             {'action' : 'callback', 'metavar': '<msg-id>',
+              'callback' : self.cb_full_documentation,
+              'group': 'Commands',
               'help' : "Generate pylint's full documentation."}),
 
             ('generate-rcfile',
@@ -831,17 +838,17 @@ There are 5 kind of message types :
     * (R) refactor, for bad code smell                                          
     * (W) warning, for python specific problems                                 
     * (E) error, for probable bugs in the code                                  
-    * (F) fatal, if an error occured which prevented pylint from doing further
+    * (F) fatal, if an error occurred which prevented pylint from doing further
 processing.
         ''')
         linter.add_help_section('Output status code', '''
 Pylint should leave with following status code:                                 
     * 0 if everything went fine                                                 
-    * 1 if some fatal message issued                                            
-    * 2 if some error message issued                                            
-    * 4 if some warning message issued                                          
-    * 8 if some refactor message issued                                         
-    * 16 if some convention message issued                                      
+    * 1 if a fatal message was issued                                           
+    * 2 if an error message was issued                                          
+    * 4 if a warning message was issued                                         
+    * 8 if a refactor message was issued                                        
+    * 16 if a convention message was issued                                     
     * 32 on usage error                                                         
                                                                                 
 status 1 to 16 will be bit-ORed so you can know which different categories has
@@ -859,7 +866,7 @@ been issued by analysing pylint output status code
         # provide options) have been registered
         linter.load_config_file()
         if reporter:
-            # if a custom reporter is provided as argument, it may be overriden
+            # if a custom reporter is provided as argument, it may be overridden
             # by file parameters, so re-set it here, but before command line
             # parsing so it's still overrideable by command line option
             linter.set_reporter(reporter)
@@ -886,11 +893,11 @@ been issued by analysing pylint output status code
         sys.exit(self.linter.msg_status)
 
     def cb_set_rcfile(self, name, value):
-        """callback for option preprocessing (ie before optik parsing)"""
+        """callback for option preprocessing (i.e. before optik parsing)"""
         self._rcfile = value
 
     def cb_add_plugins(self, name, value):
-        """callback for option preprocessing (ie before optik parsing)"""
+        """callback for option preprocessing (i.e. before optik parsing)"""
         self._plugins.extend(splitstrip(value))
 
     def cb_error_mode(self, *args, **kwargs):
@@ -901,7 +908,7 @@ been issued by analysing pylint output status code
         * do not save execution information
         """
         self.linter.disable_noerror_checkers()
-        self.linter.set_option('disable-msg-cat', 'WCRFI')
+        self.linter.set_option('disable-msg-cat', 'WCRI')
         self.linter.set_option('reports', False)
         self.linter.set_option('persistent', False)
 
@@ -921,9 +928,14 @@ been issued by analysing pylint output status code
         self.linter.help_message(splitstrip(value))
         sys.exit(0)
 
-    def cb_list_messages(self, option, opt_name, value, parser):
+    def cb_full_documentation(self, option, opt_name, value, parser):
+        """optik callback for printing full documentation"""
+        self.linter.print_full_documentation()
+        sys.exit(0)
+
+    def cb_list_messages(self, option, opt_name, value, parser): # FIXME
         """optik callback for printing available messages"""
-        self.linter.list_messages()
+        self.linter.list_sorted_messages()
         sys.exit(0)
 
 def cb_init_hook(option, opt_name, value, parser):
