@@ -14,6 +14,7 @@ class MyClass:
         """test"""
         self.correct += 2
         self.incorrect += 2
+        del self.havenot
         self.nonexistent1.truc()
         self.nonexistent2[1] = 'hehe'
 
@@ -23,3 +24,9 @@ class XYZMixin:
     """ 
     def __init__(self):
         print self.nonexistent
+
+
+class NewClass(object):
+    """use object.__setattr__"""
+    def __init__(self):
+        self.__setattr__('toto', 'tutu')
