@@ -8,7 +8,7 @@ class Meta(type):
     """the meta class"""
     def __init__(mcs, name, bases, dictionary):
         super(Meta, mcs).__init__(name, bases, dictionary)
-        print mcs._meta_args
+        print mcs, mcs._meta_args
         delattr(mcs, '_meta_args')
 
 class Test(object):
