@@ -57,10 +57,29 @@ def exception_str(ex):
     return 'in %s\n:: %s' % (ex.file, ', '.join(ex.args))
 
 class LintTestUsingModule(testlib.TestCase):            
-    package = 'input'
+    DEFAULT_PACKAGE = 'input'
+    package = DEFAULT_PACKAGE
     linter = linter
+    module = None
+    depends = None
+
+    _TEST_TYPE = 'module'
+
+    def shortDescription(self):
+        values = { 'mode' : self._TEST_TYPE,
+                   'input': self.module,
+                   'pkg':   self.package,
+                   'cls':   self.__class__.__name__}
+
+        if self.package == self.DEFAULT_PACKAGE:
+            msg = '%(mode)s test of input file "%(input)s" (%(cls)s)'
+        else:
+            msg = '%(mode)s test of input file "%(input)s" in "%(pkg)s" (%(cls)s)'
+        return msg % values
+
     def setUp(self):
         MANAGER.set_cache_size(200) # reset cache
+
     def test_functionality(self):
         tocheck = [self.package+'.'+self.module]
         if self.depends:
@@ -98,6 +117,8 @@ class LintTestUsingModule(testlib.TestCase):
 
 class LintTestUsingFile(LintTestUsingModule):            
                 
+    _TEST_TYPE = 'file'
+
     def test_functionality(self):
         tocheck = [self.package+'/' + self.module + '.py']
         if self.depends:
@@ -107,7 +128,8 @@ class LintTestUsingFile(LintTestUsingModule):
 
 class TestTests(testlib.TestCase):
     """check that all testable messages have been checked"""
-    def test(self):
+    @testlib.tag('coverage')
+    def test_exhaustivity(self):
         # skip fatal messages
         todo = [msgid for msgid in linter._messages.keys() if msgid[0] != 'F']
         for msgid in test_reporter.message_ids.keys():
@@ -161,12 +183,13 @@ def make_tests(filter_rgx):
         if not is_to_run(module_file):
             continue
         base = module_file.replace('func_', '').replace('.py', '')
-        dependancies = get_tests_info(base, '.py')
+        dependencies = get_tests_info(base, '.py')
         
         class LintTestUsingModuleTC(LintTestUsingModule):
             module = module_file.replace('.py', '')
             output = messages_file
-            depends = dependancies or None
+            depends = dependencies or None
+            tags = testlib.Tags(('generated','pylint_input_%s' % module))
         tests.append(LintTestUsingModuleTC)
 
         if MODULES_ONLY:
@@ -175,7 +198,8 @@ def make_tests(filter_rgx):
         class LintTestUsingFileTC(LintTestUsingFile):
             module = module_file.replace('.py', '')
             output = exists(messages_file + '2') and (messages_file + '2') or messages_file
-            depends = dependancies or None
+            depends = dependencies or None
+            tags = testlib.Tags(('generated', 'pylint_input_%s' % module))
         tests.append(LintTestUsingFileTC)
         
 ##     # special test for f0003
@@ -183,7 +207,7 @@ def make_tests(filter_rgx):
 ##     class LintTestSubclass(LintTest):
 ##         module = module_file.replace('.pyc', '')
 ##         output = messages_file
-##         depends = dependancies or None
+##         depends = dependencies or None
 ##     tests.append(LintTestSubclass)
             
     class LintBuiltinModuleTest(LintTestUsingModule):
