@@ -12,10 +12,10 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import shutil
 import sys
 import os
 import tempfile
+from shutil import rmtree
 from os.path import join, basename, dirname, isdir, abspath
 from cStringIO import StringIO
 
@@ -28,7 +28,7 @@ from pylint.utils import sort_msgs
 from pylint import checkers
 
 class SortMessagesTC(TestCase):
-    
+
     def test(self):
         l = ['E0501', 'E0503', 'F0002', 'I0201', 'W0540',
              'R0202', 'F0203', 'R0220', 'W0321', 'I0001']
@@ -43,7 +43,7 @@ try:
     raise AssertionError
 except AssertionError:
     optimized = False
-    
+
 class GetNoteMessageTC(TestCase):
     def test(self):
         msg = None
@@ -75,22 +75,22 @@ class RunTC(TestCase):
             sys.stdout = sys.__stdout__
             sys.stderr = sys.__stderr__
 
-        
+
 class PyLinterTC(TestCase):
-    
+
     def setUp(self):
         self.linter = PyLinter()
         self.linter.disable_message_category('I')
         self.linter.config.persistent = 0
         # register checkers
         checkers.initialize(self.linter)
-        
+
     def test_message_help(self):
         msg = self.linter.get_message_help('F0001', checkerref=True)
-        expected = ':F0001:\n  Used when an error occured preventing the analysis of a module (unable to find\n  it for instance). This message belongs to the master checker.'
+        expected = ':F0001:\n  Used when an error occurred preventing the analysis of a module (unable to\n  find it for instance). This message belongs to the master checker.'
         self.assertTextEqual(msg, expected)
         self.assertRaises(UnknownMessage, self.linter.get_message_help, 'YB12')
-        
+
     def test_enable_message(self):
         linter = self.linter
         linter.open()
@@ -103,7 +103,7 @@ class PyLinterTC(TestCase):
         self.assert_(not linter.is_message_enabled('W0102', 1))
         linter.set_current_module('tutu')
         self.assert_(not linter.is_message_enabled('W0101'))
-        self.assert_(linter.is_message_enabled('W0102'))        
+        self.assert_(linter.is_message_enabled('W0102'))
         linter.enable_message('W0101', scope='package')
         linter.enable_message('W0102', scope='module', line=1)
         self.assert_(linter.is_message_enabled('W0101'))
@@ -121,7 +121,7 @@ class PyLinterTC(TestCase):
         self.assert_(not linter.is_message_enabled('R0102'))
         linter.set_current_module('tutu')
         self.assert_(not linter.is_message_enabled('W0101'))
-        self.assert_(linter.is_message_enabled('R0102'))        
+        self.assert_(linter.is_message_enabled('R0102'))
         linter.enable_message_category('W', scope='package')
         linter.enable_message_category('R', scope='module')
         self.assert_(linter.is_message_enabled('W0101'))
@@ -146,7 +146,7 @@ class PyLinterTC(TestCase):
         # meth3
         self.assert_(not linter.is_message_enabled('E1101', 24))
         self.assert_(linter.is_message_enabled('E1101', 26))
-        # meth4        
+        # meth4
         self.assert_(not linter.is_message_enabled('E1101', 32))
         self.assert_(linter.is_message_enabled('E1101', 36))
         # meth5
@@ -160,7 +160,7 @@ class PyLinterTC(TestCase):
         self.assert_(linter.is_message_enabled('E1101', 61))
         self.assert_(not linter.is_message_enabled('E1101', 64))
         self.assert_(not linter.is_message_enabled('E1101', 66))
-        
+
         self.assert_(linter.is_message_enabled('E0602', 57))
         self.assert_(linter.is_message_enabled('E0602', 61))
         self.assert_(not linter.is_message_enabled('E0602', 62))
@@ -171,7 +171,7 @@ class PyLinterTC(TestCase):
         self.assert_(linter.is_message_enabled('E1101', 72))
         self.assert_(linter.is_message_enabled('E1101', 75))
         self.assert_(linter.is_message_enabled('E1101', 77))
-        
+
     def test_list_messages(self):
         sys.stdout = StringIO()
         try:
@@ -219,15 +219,15 @@ class PyLinterTC(TestCase):
         self.assertEquals(sorted([c.name for c in self.linter._checkers.values()
                                   if c.is_enabled()]),
                           ['basic', 'classes', 'exceptions', 'format', 'imports',
-                           'master', 'metrics', 'miscellaneous', 'newstyle',
-                           'similarities', 'typecheck', 'variables'])
-        
+                           'logging', 'master', 'metrics', 'miscellaneous', 'newstyle',
+                           'similarities', 'string_format', 'typecheck', 'variables'])
+
     def test_enable_checkers2(self):
         self.linter.enable_checkers(['design'], True)
         self.assertEquals(sorted([c.name for c in self.linter._checkers.values()
                            if c.is_enabled()]),
                           ['design', 'master'])
-                          
+
 from pylint import config
 
 class ConfigTC(TestCase):
@@ -258,7 +258,10 @@ class ConfigTC(TestCase):
             del os.environ['PYLINTHOME']
 
     def test_pylintrc(self):
+        fake_home = tempfile.mkdtemp('fake-home')
+        home = os.environ['HOME']
         try:
+            os.environ['HOME'] = fake_home
             self.assertEquals(config.find_pylintrc(), None)
             os.environ['PYLINTRC'] = join(tempfile.gettempdir(), '.pylintrc')
             self.assertEquals(config.find_pylintrc(), None)
@@ -266,6 +269,8 @@ class ConfigTC(TestCase):
             self.assertEquals(config.find_pylintrc(), None)
         finally:
             os.environ.pop('PYLINTRC', '')
+            os.environ['HOME'] = home
+            rmtree(fake_home, ignore_errors=True)
             reload(config)
 
     def test_pylintrc_parentdir(self):
@@ -274,7 +279,14 @@ class ConfigTC(TestCase):
             create_files(['a/pylintrc', 'a/b/__init__.py', 'a/b/pylintrc',
                           'a/b/c/__init__.py', 'a/b/c/d/__init__.py'], chroot)
             os.chdir(chroot)
-            self.assertEquals(config.find_pylintrc(), None)
+            fake_home = tempfile.mkdtemp('fake-home')
+            home = os.environ['HOME']
+            try:
+                os.environ['HOME'] = fake_home
+                self.assertEquals(config.find_pylintrc(), None)
+            finally:
+                os.environ['HOME'] = home
+                os.rmdir(fake_home)
             results = {'a'       : join(chroot, 'a', 'pylintrc'),
                        'a/b'     : join(chroot, 'a', 'b', 'pylintrc'),
                        'a/b/c'   : join(chroot, 'a', 'b', 'pylintrc'),
@@ -285,26 +297,31 @@ class ConfigTC(TestCase):
                 self.assertEquals(config.find_pylintrc(), expected)
         finally:
             os.chdir(HERE)
-            shutil.rmtree(chroot)
-     
+            rmtree(chroot)
+
 
     def test_pylintrc_parentdir_no_package(self):
         chroot = tempfile.mkdtemp()
+        fake_home = tempfile.mkdtemp('fake-home')
+        home = os.environ['HOME']
+        os.environ['HOME'] = fake_home
         try:
             create_files(['a/pylintrc', 'a/b/pylintrc', 'a/b/c/d/__init__.py'], chroot)
             os.chdir(chroot)
             self.assertEquals(config.find_pylintrc(), None)
             results = {'a'       : join(chroot, 'a', 'pylintrc'),
                        'a/b'     : join(chroot, 'a', 'b', 'pylintrc'),
-                       'a/b/c'   : None, 
-                       'a/b/c/d' : None, 
+                       'a/b/c'   : None,
+                       'a/b/c/d' : None,
                        }
             for basedir, expected in results.items():
                 os.chdir(join(chroot, basedir))
                 self.assertEquals(config.find_pylintrc(), expected)
         finally:
+            os.environ['HOME'] = home
+            rmtree(fake_home, ignore_errors=True)
             os.chdir(HERE)
-            shutil.rmtree(chroot)
+            rmtree(chroot)
 
 if __name__ == '__main__':
     unittest_main()
